@@ -1,4 +1,4 @@
-epi.sssimpleestb <- function(N = 1E+06, Py, epsilon, error = "relative", se, sp, nfractional = FALSE, conf.level = 0.95) 
+epi.sssimpleestb <- function(N = NA, Py, epsilon, error = "relative", se, sp, nfractional = FALSE, conf.level = 0.95) 
 {
     N. <- 1 - ((1 - conf.level) / 2)
     z <- qnorm(N., mean = 0, sd = 1)
@@ -14,17 +14,12 @@ epi.sssimpleestb <- function(N = 1E+06, Py, epsilon, error = "relative", se, sp,
     # Page 74 Levy and Lemeshow (equation 3.16):
     # n <- (z^2 * N * (1 - Py) * Py) / (((N - 1) * (epsilon.r^2) * Py^2) + (z^2 * Py * (1 - Py)))
 
-    f <- n / N
-    if(f > 0.10){n <- n / (1 + n/N)}
-    
-    if(nfractional == TRUE){
-      n <- n
-    }
-    
-    if(nfractional == FALSE){
-      n <- ceiling(n)
-    }
+    # Finite population correction:
+    n <- ifelse(is.na(N), n, (n * N) / (n + (N - 1)))
     
+    # Fractional:
+    n <- ifelse(nfractional == TRUE, n, ceiling(n))
+
     rval <- n
     return(rval)
 }
